@@ -48,6 +48,7 @@ from .type_defs import (
     DescribeClusterV2ResponseTypeDef,
     DescribeConfigurationResponseTypeDef,
     DescribeConfigurationRevisionResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     EncryptionInfoTypeDef,
     GetBootstrapBrokersResponseTypeDef,
     GetCompatibleKafkaVersionsResponseTypeDef,
@@ -150,19 +151,27 @@ class KafkaClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#close)
+        """
+
     def create_cluster(
         self,
         *,
-        BrokerNodeGroupInfo: "BrokerNodeGroupInfoTypeDef",
+        BrokerNodeGroupInfo: BrokerNodeGroupInfoTypeDef,
         ClusterName: str,
         KafkaVersion: str,
         NumberOfBrokerNodes: int,
-        ClientAuthentication: "ClientAuthenticationTypeDef" = ...,
-        ConfigurationInfo: "ConfigurationInfoTypeDef" = ...,
-        EncryptionInfo: "EncryptionInfoTypeDef" = ...,
+        ClientAuthentication: ClientAuthenticationTypeDef = ...,
+        ConfigurationInfo: ConfigurationInfoTypeDef = ...,
+        EncryptionInfo: EncryptionInfoTypeDef = ...,
         EnhancedMonitoring: EnhancedMonitoringType = ...,
-        OpenMonitoring: "OpenMonitoringInfoTypeDef" = ...,
-        LoggingInfo: "LoggingInfoTypeDef" = ...,
+        OpenMonitoring: OpenMonitoringInfoTypeDef = ...,
+        LoggingInfo: LoggingInfoTypeDef = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateClusterResponseTypeDef:
         """
@@ -177,8 +186,8 @@ class KafkaClient(BaseClient):
         *,
         ClusterName: str,
         Tags: Mapping[str, str] = ...,
-        Provisioned: "ProvisionedRequestTypeDef" = ...,
-        Serverless: "ServerlessRequestTypeDef" = ...
+        Provisioned: ProvisionedRequestTypeDef = ...,
+        Serverless: ServerlessRequestTypeDef = ...
     ) -> CreateClusterV2ResponseTypeDef:
         """
         Creates a new MSK cluster.
@@ -403,7 +412,9 @@ class KafkaClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#reboot_broker)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Mapping[str, str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Adds tags to the specified MSK resource.
 
@@ -411,7 +422,9 @@ class KafkaClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes the tags associated with the keys that are provided in the query.
 
@@ -434,7 +447,7 @@ class KafkaClient(BaseClient):
         *,
         ClusterArn: str,
         CurrentVersion: str,
-        TargetBrokerEBSVolumeInfo: Sequence["BrokerEBSVolumeInfoTypeDef"]
+        TargetBrokerEBSVolumeInfo: Sequence[BrokerEBSVolumeInfoTypeDef]
     ) -> UpdateBrokerStorageResponseTypeDef:
         """
         Updates the EBS storage associated with MSK brokers.
@@ -454,7 +467,7 @@ class KafkaClient(BaseClient):
         """
 
     def update_cluster_configuration(
-        self, *, ClusterArn: str, ConfigurationInfo: "ConfigurationInfoTypeDef", CurrentVersion: str
+        self, *, ClusterArn: str, ConfigurationInfo: ConfigurationInfoTypeDef, CurrentVersion: str
     ) -> UpdateClusterConfigurationResponseTypeDef:
         """
         Updates the cluster with the configuration that is specified in the request
@@ -470,7 +483,7 @@ class KafkaClient(BaseClient):
         ClusterArn: str,
         CurrentVersion: str,
         TargetKafkaVersion: str,
-        ConfigurationInfo: "ConfigurationInfoTypeDef" = ...
+        ConfigurationInfo: ConfigurationInfoTypeDef = ...
     ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
         Updates the Apache Kafka version for the cluster.
@@ -494,7 +507,7 @@ class KafkaClient(BaseClient):
         """
 
     def update_connectivity(
-        self, *, ClusterArn: str, ConnectivityInfo: "ConnectivityInfoTypeDef", CurrentVersion: str
+        self, *, ClusterArn: str, ConnectivityInfo: ConnectivityInfoTypeDef, CurrentVersion: str
     ) -> UpdateConnectivityResponseTypeDef:
         """
         Updates the cluster's connectivity configuration.
@@ -509,8 +522,8 @@ class KafkaClient(BaseClient):
         ClusterArn: str,
         CurrentVersion: str,
         EnhancedMonitoring: EnhancedMonitoringType = ...,
-        OpenMonitoring: "OpenMonitoringInfoTypeDef" = ...,
-        LoggingInfo: "LoggingInfoTypeDef" = ...
+        OpenMonitoring: OpenMonitoringInfoTypeDef = ...,
+        LoggingInfo: LoggingInfoTypeDef = ...
     ) -> UpdateMonitoringResponseTypeDef:
         """
         Updates the monitoring settings for the cluster.
@@ -524,8 +537,8 @@ class KafkaClient(BaseClient):
         *,
         ClusterArn: str,
         CurrentVersion: str,
-        ClientAuthentication: "ClientAuthenticationTypeDef" = ...,
-        EncryptionInfo: "EncryptionInfoTypeDef" = ...
+        ClientAuthentication: ClientAuthenticationTypeDef = ...,
+        EncryptionInfo: EncryptionInfoTypeDef = ...
     ) -> UpdateSecurityResponseTypeDef:
         """
         Updates the security settings for the cluster.
