@@ -79,7 +79,7 @@ class ListClusterOperationsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ClusterArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListClusterOperationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
@@ -94,7 +94,7 @@ class ListClustersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ClusterNameFilter: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ClusterNameFilter: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListClustersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
@@ -113,7 +113,7 @@ class ListClustersV2Paginator(Boto3Paginator):
         *,
         ClusterNameFilter: str = ...,
         ClusterTypeFilter: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListClustersV2ResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClustersV2.paginate)
@@ -128,7 +128,7 @@ class ListConfigurationRevisionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Arn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Arn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListConfigurationRevisionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
@@ -143,7 +143,7 @@ class ListConfigurationsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListConfigurationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
@@ -158,7 +158,7 @@ class ListKafkaVersionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListKafkaVersionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
@@ -173,7 +173,7 @@ class ListNodesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ClusterArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListNodesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
@@ -188,7 +188,7 @@ class ListScramSecretsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ClusterArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListScramSecretsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
